# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.list_targets_output import ListTargetsOutput  # noqa: E501
from akeyless.rest import ApiException

class TestListTargetsOutput(unittest.TestCase):
    """ListTargetsOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListTargetsOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.list_targets_output.ListTargetsOutput()  # noqa: E501
        if include_optional :
            return ListTargetsOutput(
                next_page = '0', 
                targets = [
                    akeyless.models.target_includes_target_details/.Target includes target details.(
                        comment = '0', 
                        protection_key_name = '0', 
                        target_id = 56, 
                        target_items_assoc = [
                            akeyless.models.target_item_association.TargetItemAssociation(
                                assoc_id = '0', 
                                item_name = '0', )
                            ], 
                        target_name = '0', 
                        target_type = '0', 
                        with_customer_fragment = True, )
                    ]
            )
        else :
            return ListTargetsOutput(
        )

    def testListTargetsOutput(self):
        """Test ListTargetsOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
