# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.target_type_details_input import TargetTypeDetailsInput  # noqa: E501
from akeyless.rest import ApiException

class TestTargetTypeDetailsInput(unittest.TestCase):
    """TargetTypeDetailsInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TargetTypeDetailsInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.target_type_details_input.TargetTypeDetailsInput()  # noqa: E501
        if include_optional :
            return TargetTypeDetailsInput(
                artifactory_admin_apikey = '0', 
                artifactory_admin_username = '0', 
                artifactory_base_url = '0', 
                aws_access_key_id = '0', 
                aws_region = '0', 
                aws_secret_access_key = '0', 
                aws_session_token = '0', 
                azure_client_id = '0', 
                azure_client_secret = '0', 
                azure_tenant_id = '0', 
                chef_server_host_name = '0', 
                chef_server_key = '0', 
                chef_server_port = '0', 
                chef_server_url = '0', 
                chef_server_username = '0', 
                chef_skip_ssl = True, 
                db_host_name = '0', 
                db_name = '0', 
                db_port = '0', 
                db_pwd = '0', 
                db_server_certificates = '0', 
                db_server_name = '0', 
                db_user_name = '0', 
                eks_access_key_id = '0', 
                eks_assume_role = '0', 
                eks_cluster_ca_certificate = '0', 
                eks_cluster_endpoint = '0', 
                eks_cluster_name = '0', 
                eks_region = '0', 
                eks_secret_access_key = '0', 
                gcp_service_account_email = '0', 
                gcp_service_account_key = [
                    56
                    ], 
                gke_cluster_ca_certificate = '0', 
                gke_cluster_endpoint = '0', 
                gke_cluster_name = '0', 
                gke_service_account_key = '0', 
                gke_service_account_name = '0', 
                host = '0', 
                mongodb_atlas = True, 
                mongodb_atlas_api_private_key = '0', 
                mongodb_atlas_api_public_key = '0', 
                mongodb_atlas_project_id = '0', 
                mongodb_db_name = '0', 
                mongodb_default_auth_db = '0', 
                mongodb_host_port = '0', 
                mongodb_password = '0', 
                mongodb_uri_connection = '0', 
                mongodb_uri_options = '0', 
                mongodb_username = '0', 
                password = '0', 
                port = '0', 
                private_key = '0', 
                private_key_password = '0', 
                rabbitmq_server_password = '0', 
                rabbitmq_server_uri = '0', 
                rabbitmq_server_user = '0', 
                sf_account = '0', 
                url = '0', 
                username = '0', 
                venafi_api_key = '0', 
                venafi_base_url = '0', 
                venafi_tpp_password = '0', 
                venafi_tpp_username = '0', 
                venafi_use_tpp = True, 
                venafi_zone = '0'
            )
        else :
            return TargetTypeDetailsInput(
        )

    def testTargetTypeDetailsInput(self):
        """Test TargetTypeDetailsInput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
