# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.secure_remote_access import SecureRemoteAccess  # noqa: E501
from akeyless.rest import ApiException

class TestSecureRemoteAccess(unittest.TestCase):
    """SecureRemoteAccess unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecureRemoteAccess
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.secure_remote_access.SecureRemoteAccess()  # noqa: E501
        if include_optional :
            return SecureRemoteAccess(
                account_id = '0', 
                allow_port_forwarding = True, 
                bastion_api = '0', 
                bastion_issuer = '0', 
                bastion_issuer_id = 56, 
                bastion_ssh = '0', 
                category = '0', 
                dashboard_url = '0', 
                db_name = '0', 
                domain = '0', 
                enable = True, 
                endpoint = '0', 
                host = [
                    '0'
                    ], 
                is_cli = True, 
                is_web = True, 
                isolated = True, 
                native = True, 
                region = '0', 
                schema = '0', 
                ssh_password = True, 
                ssh_private_key = True, 
                ssh_user = '0', 
                url = '0'
            )
        else :
            return SecureRemoteAccess(
        )

    def testSecureRemoteAccess(self):
        """Test SecureRemoteAccess"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
