# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AWSIAMAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'list[str]',
        'arn': 'list[str]',
        'resource_id': 'list[str]',
        'role_id': 'list[str]',
        'role_name': 'list[str]',
        'sts_endpoint': 'str',
        'user_id': 'list[str]',
        'user_name': 'list[str]'
    }

    attribute_map = {
        'account_id': 'account_id',
        'arn': 'arn',
        'resource_id': 'resource_id',
        'role_id': 'role_id',
        'role_name': 'role_name',
        'sts_endpoint': 'sts_endpoint',
        'user_id': 'user_id',
        'user_name': 'user_name'
    }

    def __init__(self, account_id=None, arn=None, resource_id=None, role_id=None, role_name=None, sts_endpoint=None, user_id=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """AWSIAMAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._arn = None
        self._resource_id = None
        self._role_id = None
        self._role_name = None
        self._sts_endpoint = None
        self._user_id = None
        self._user_name = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if arn is not None:
            self.arn = arn
        if resource_id is not None:
            self.resource_id = resource_id
        if role_id is not None:
            self.role_id = role_id
        if role_name is not None:
            self.role_name = role_name
        if sts_endpoint is not None:
            self.sts_endpoint = sts_endpoint
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name

    @property
    def account_id(self):
        """Gets the account_id of this AWSIAMAccessRules.  # noqa: E501

        The list of account ids that the login is restricted to.  # noqa: E501

        :return: The account_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AWSIAMAccessRules.

        The list of account ids that the login is restricted to.  # noqa: E501

        :param account_id: The account_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._account_id = account_id

    @property
    def arn(self):
        """Gets the arn of this AWSIAMAccessRules.  # noqa: E501

        The list of ARNs that the login is restricted to.  # noqa: E501

        :return: The arn of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._arn

    @arn.setter
    def arn(self, arn):
        """Sets the arn of this AWSIAMAccessRules.

        The list of ARNs that the login is restricted to.  # noqa: E501

        :param arn: The arn of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._arn = arn

    @property
    def resource_id(self):
        """Gets the resource_id of this AWSIAMAccessRules.  # noqa: E501

        The list of resource ids that the login is restricted to.  # noqa: E501

        :return: The resource_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AWSIAMAccessRules.

        The list of resource ids that the login is restricted to.  # noqa: E501

        :param resource_id: The resource_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._resource_id = resource_id

    @property
    def role_id(self):
        """Gets the role_id of this AWSIAMAccessRules.  # noqa: E501

        The list of role ids that the login is restricted to.  # noqa: E501

        :return: The role_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this AWSIAMAccessRules.

        The list of role ids that the login is restricted to.  # noqa: E501

        :param role_id: The role_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this AWSIAMAccessRules.  # noqa: E501

        The list of role names that the login is restricted to.  # noqa: E501

        :return: The role_name of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this AWSIAMAccessRules.

        The list of role names that the login is restricted to.  # noqa: E501

        :param role_name: The role_name of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._role_name = role_name

    @property
    def sts_endpoint(self):
        """Gets the sts_endpoint of this AWSIAMAccessRules.  # noqa: E501

        The sts URL.  # noqa: E501

        :return: The sts_endpoint of this AWSIAMAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._sts_endpoint

    @sts_endpoint.setter
    def sts_endpoint(self, sts_endpoint):
        """Sets the sts_endpoint of this AWSIAMAccessRules.

        The sts URL.  # noqa: E501

        :param sts_endpoint: The sts_endpoint of this AWSIAMAccessRules.  # noqa: E501
        :type: str
        """

        self._sts_endpoint = sts_endpoint

    @property
    def user_id(self):
        """Gets the user_id of this AWSIAMAccessRules.  # noqa: E501

        The list of user ids that the login is restricted to.  # noqa: E501

        :return: The user_id of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AWSIAMAccessRules.

        The list of user ids that the login is restricted to.  # noqa: E501

        :param user_id: The user_id of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this AWSIAMAccessRules.  # noqa: E501

        The list of user names that the login is restricted to.  # noqa: E501

        :return: The user_name of this AWSIAMAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AWSIAMAccessRules.

        The list of user names that the login is restricted to.  # noqa: E501

        :param user_name: The user_name of this AWSIAMAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AWSIAMAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AWSIAMAccessRules):
            return True

        return self.to_dict() != other.to_dict()
