# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class MigrationStatusReplyObj(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'duration_time': 'str',
        'last_status_message': 'str',
        'max_name_length': 'int',
        'max_value_length': 'int',
        'migration_id': 'str',
        'migration_items': 'MigrationItems',
        'migration_name': 'str',
        'migration_state': 'str',
        'migration_type': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'duration_time': 'duration_time',
        'last_status_message': 'last_status_message',
        'max_name_length': 'max_name_length',
        'max_value_length': 'max_value_length',
        'migration_id': 'migration_id',
        'migration_items': 'migration_items',
        'migration_name': 'migration_name',
        'migration_state': 'migration_state',
        'migration_type': 'migration_type',
        'start_time': 'start_time'
    }

    def __init__(self, duration_time=None, last_status_message=None, max_name_length=None, max_value_length=None, migration_id=None, migration_items=None, migration_name=None, migration_state=None, migration_type=None, start_time=None, local_vars_configuration=None):  # noqa: E501
        """MigrationStatusReplyObj - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._duration_time = None
        self._last_status_message = None
        self._max_name_length = None
        self._max_value_length = None
        self._migration_id = None
        self._migration_items = None
        self._migration_name = None
        self._migration_state = None
        self._migration_type = None
        self._start_time = None
        self.discriminator = None

        if duration_time is not None:
            self.duration_time = duration_time
        if last_status_message is not None:
            self.last_status_message = last_status_message
        if max_name_length is not None:
            self.max_name_length = max_name_length
        if max_value_length is not None:
            self.max_value_length = max_value_length
        if migration_id is not None:
            self.migration_id = migration_id
        if migration_items is not None:
            self.migration_items = migration_items
        if migration_name is not None:
            self.migration_name = migration_name
        if migration_state is not None:
            self.migration_state = migration_state
        if migration_type is not None:
            self.migration_type = migration_type
        if start_time is not None:
            self.start_time = start_time

    @property
    def duration_time(self):
        """Gets the duration_time of this MigrationStatusReplyObj.  # noqa: E501


        :return: The duration_time of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._duration_time

    @duration_time.setter
    def duration_time(self, duration_time):
        """Sets the duration_time of this MigrationStatusReplyObj.


        :param duration_time: The duration_time of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._duration_time = duration_time

    @property
    def last_status_message(self):
        """Gets the last_status_message of this MigrationStatusReplyObj.  # noqa: E501


        :return: The last_status_message of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._last_status_message

    @last_status_message.setter
    def last_status_message(self, last_status_message):
        """Sets the last_status_message of this MigrationStatusReplyObj.


        :param last_status_message: The last_status_message of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._last_status_message = last_status_message

    @property
    def max_name_length(self):
        """Gets the max_name_length of this MigrationStatusReplyObj.  # noqa: E501


        :return: The max_name_length of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._max_name_length

    @max_name_length.setter
    def max_name_length(self, max_name_length):
        """Sets the max_name_length of this MigrationStatusReplyObj.


        :param max_name_length: The max_name_length of this MigrationStatusReplyObj.  # noqa: E501
        :type: int
        """

        self._max_name_length = max_name_length

    @property
    def max_value_length(self):
        """Gets the max_value_length of this MigrationStatusReplyObj.  # noqa: E501


        :return: The max_value_length of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._max_value_length

    @max_value_length.setter
    def max_value_length(self, max_value_length):
        """Sets the max_value_length of this MigrationStatusReplyObj.


        :param max_value_length: The max_value_length of this MigrationStatusReplyObj.  # noqa: E501
        :type: int
        """

        self._max_value_length = max_value_length

    @property
    def migration_id(self):
        """Gets the migration_id of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_id of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_id

    @migration_id.setter
    def migration_id(self, migration_id):
        """Sets the migration_id of this MigrationStatusReplyObj.


        :param migration_id: The migration_id of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_id = migration_id

    @property
    def migration_items(self):
        """Gets the migration_items of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_items of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: MigrationItems
        """
        return self._migration_items

    @migration_items.setter
    def migration_items(self, migration_items):
        """Sets the migration_items of this MigrationStatusReplyObj.


        :param migration_items: The migration_items of this MigrationStatusReplyObj.  # noqa: E501
        :type: MigrationItems
        """

        self._migration_items = migration_items

    @property
    def migration_name(self):
        """Gets the migration_name of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_name of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_name

    @migration_name.setter
    def migration_name(self, migration_name):
        """Sets the migration_name of this MigrationStatusReplyObj.


        :param migration_name: The migration_name of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_name = migration_name

    @property
    def migration_state(self):
        """Gets the migration_state of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_state of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_state

    @migration_state.setter
    def migration_state(self, migration_state):
        """Sets the migration_state of this MigrationStatusReplyObj.


        :param migration_state: The migration_state of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_state = migration_state

    @property
    def migration_type(self):
        """Gets the migration_type of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_type of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_type

    @migration_type.setter
    def migration_type(self, migration_type):
        """Sets the migration_type of this MigrationStatusReplyObj.


        :param migration_type: The migration_type of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_type = migration_type

    @property
    def start_time(self):
        """Gets the start_time of this MigrationStatusReplyObj.  # noqa: E501


        :return: The start_time of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this MigrationStatusReplyObj.


        :param start_time: The start_time of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MigrationStatusReplyObj):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MigrationStatusReplyObj):
            return True

        return self.to_dict() != other.to_dict()
