# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.sign_pki_cert_with_classic_key import SignPKICertWithClassicKey  # noqa: E501
from akeyless.rest import ApiException

class TestSignPKICertWithClassicKey(unittest.TestCase):
    """SignPKICertWithClassicKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SignPKICertWithClassicKey
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.sign_pki_cert_with_classic_key.SignPKICertWithClassicKey()  # noqa: E501
        if include_optional :
            return SignPKICertWithClassicKey(
                common_name = '0', 
                country = '0', 
                display_id = '0', 
                dns_names = '0', 
                key_usage = 'DigitalSignature,KeyAgreement,KeyEncipherment', 
                locality = '0', 
                organizational_units = '0', 
                organizations = '0', 
                password = '0', 
                postal_code = '0', 
                province = '0', 
                public_key_pem_data = '0', 
                signing_method = '0', 
                street_address = '0', 
                token = '0', 
                ttl = 56, 
                uid_token = '0', 
                uri_sans = '0', 
                username = '0', 
                version = 56
            )
        else :
            return SignPKICertWithClassicKey(
                display_id = '0',
                signing_method = '0',
                ttl = 56,
                version = 56,
        )

    def testSignPKICertWithClassicKey(self):
        """Test SignPKICertWithClassicKey"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
