# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.create_pki_cert_issuer import CreatePKICertIssuer  # noqa: E501
from akeyless.rest import ApiException

class TestCreatePKICertIssuer(unittest.TestCase):
    """CreatePKICertIssuer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreatePKICertIssuer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.create_pki_cert_issuer.CreatePKICertIssuer()  # noqa: E501
        if include_optional :
            return CreatePKICertIssuer(
                allow_any_name = True, 
                allow_subdomains = True, 
                allowed_domains = '0', 
                allowed_uri_sans = '0', 
                client_flag = True, 
                code_signing_flag = True, 
                country = '0', 
                key_usage = 'DigitalSignature,KeyAgreement,KeyEncipherment', 
                locality = '0', 
                metadata = '0', 
                name = '0', 
                not_enforce_hostnames = True, 
                not_require_cn = True, 
                organizational_units = '0', 
                organizations = '0', 
                postal_code = '0', 
                province = '0', 
                server_flag = True, 
                signer_key_name = '0', 
                street_address = '0', 
                token = '0', 
                ttl = 56, 
                uid_token = '0'
            )
        else :
            return CreatePKICertIssuer(
                name = '0',
                signer_key_name = '0',
                ttl = 56,
        )

    def testCreatePKICertIssuer(self):
        """Test CreatePKICertIssuer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
