# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.universal_identity_details import UniversalIdentityDetails  # noqa: E501
from akeyless.rest import ApiException

class TestUniversalIdentityDetails(unittest.TestCase):
    """UniversalIdentityDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UniversalIdentityDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.universal_identity_details.UniversalIdentityDetails()  # noqa: E501
        if include_optional :
            return UniversalIdentityDetails(
                max_depth = 56, 
                number_of_tokens = 56, 
                root = akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                    children = {
                        'key' : akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                            comment = '0', 
                            deny_inheritance = True, 
                            deny_rotate = True, 
                            depth = 56, 
                            expired_date = '0', 
                            id = '0', 
                            last_rotate = '0', 
                            revoked = True, 
                            ttl = 56, )
                        }, 
                    comment = '0', 
                    deny_inheritance = True, 
                    deny_rotate = True, 
                    depth = 56, 
                    expired_date = '0', 
                    id = '0', 
                    last_rotate = '0', 
                    revoked = True, 
                    ttl = 56, )
            )
        else :
            return UniversalIdentityDetails(
        )

    def testUniversalIdentityDetails(self):
        """Test UniversalIdentityDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
