# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.ssh_certificate_issue_details import SSHCertificateIssueDetails  # noqa: E501
from akeyless.rest import ApiException

class TestSSHCertificateIssueDetails(unittest.TestCase):
    """SSHCertificateIssueDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SSHCertificateIssueDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.ssh_certificate_issue_details.SSHCertificateIssueDetails()  # noqa: E501
        if include_optional :
            return SSHCertificateIssueDetails(
                allowed_domains = [
                    '0'
                    ], 
                allowed_user_key_lengths = {
                    'key' : 56
                    }, 
                allowed_users = [
                    '0'
                    ], 
                cert_type = 56, 
                critical_options = {
                    'key' : '0'
                    }, 
                extensions = {
                    'key' : '0'
                    }, 
                principals = [
                    '0'
                    ], 
                static_key_id = '0'
            )
        else :
            return SSHCertificateIssueDetails(
        )

    def testSSHCertificateIssueDetails(self):
        """Test SSHCertificateIssueDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
