# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SraInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sla': 'str',
        'tier': 'str',
        'user_type': 'str'
    }

    attribute_map = {
        'sla': 'sla',
        'tier': 'tier',
        'user_type': 'user_type'
    }

    def __init__(self, sla=None, tier=None, user_type=None, local_vars_configuration=None):  # noqa: E501
        """SraInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sla = None
        self._tier = None
        self._user_type = None
        self.discriminator = None

        if sla is not None:
            self.sla = sla
        if tier is not None:
            self.tier = tier
        if user_type is not None:
            self.user_type = user_type

    @property
    def sla(self):
        """Gets the sla of this SraInfo.  # noqa: E501


        :return: The sla of this SraInfo.  # noqa: E501
        :rtype: str
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this SraInfo.


        :param sla: The sla of this SraInfo.  # noqa: E501
        :type: str
        """

        self._sla = sla

    @property
    def tier(self):
        """Gets the tier of this SraInfo.  # noqa: E501

        Tier represents a level of extensibility the account will have, defined by various limits for different resources of Akeyless e.g - A StarterTier may have a limit of 3 Client resources and 50 Secret resources  # noqa: E501

        :return: The tier of this SraInfo.  # noqa: E501
        :rtype: str
        """
        return self._tier

    @tier.setter
    def tier(self, tier):
        """Sets the tier of this SraInfo.

        Tier represents a level of extensibility the account will have, defined by various limits for different resources of Akeyless e.g - A StarterTier may have a limit of 3 Client resources and 50 Secret resources  # noqa: E501

        :param tier: The tier of this SraInfo.  # noqa: E501
        :type: str
        """

        self._tier = tier

    @property
    def user_type(self):
        """Gets the user_type of this SraInfo.  # noqa: E501


        :return: The user_type of this SraInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this SraInfo.


        :param user_type: The user_type of this SraInfo.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SraInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SraInfo):
            return True

        return self.to_dict() != other.to_dict()
